@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,13 +9,9 @@
 
 using namespace PimCommon;
 
-AddresseeLineEditAkonadi::AddresseeLineEditAkonadi()
-{
-}
+AddresseeLineEditAkonadi::AddresseeLineEditAkonadi() = default;
 
-AddresseeLineEditAkonadi::~AddresseeLineEditAkonadi()
-{
-}
+AddresseeLineEditAkonadi::~AddresseeLineEditAkonadi() = default;
 
 Akonadi::Session *AddresseeLineEditAkonadi::akonadiSession() const
 {
